from flask import Blueprint, jsonify

from stumpf.diva_fact_schemas import ActivityFact, ActivityFactSchema
from stumpf.models import Assignment, AssignmentSchema
from stumpf.pipelines.refiner_scoring import generate_answer_tracks


refiner_bp = Blueprint('refiner', __name__)
activity_schema = ActivityFactSchema()
assignment_schema = AssignmentSchema()


@refiner_bp.route('/refiner/assignment/<uuid:assignment_id>', methods=['GET'])
def get_assignment_answer(assignment_id):
    assignment = assignment_schema.dump(Assignment.query.get_or_404(assignment_id))
    answer = assignment.get('answer')

    if answer is None:
        return 'No answer exists', 400
    try:
        tracks = generate_answer_tracks(answer)
    except Exception:
        return 'Invalid answer', 400

    activity_id = assignment['task']['args'].get('activityId')
    if activity_id is None:
        return 'Invalid task args', 400

    activity = activity_schema.dump(ActivityFact.query.get_or_404(activity_id))
    activity['tracks'] = tracks
    return jsonify(activity)


@refiner_bp.route('/refiner/fact/<uuid:fact_id>', methods=['GET'])
def get_activity_fact(fact_id):
    activity = ActivityFact.query.get_or_404(fact_id)
    return jsonify(activity_schema.dump(activity))
